.. :changelog:

History
-------

2.3.2 (2015-01-27)
==================
* Corregir bug en template, `search_result.html`

2.3.1 (2015-01-27)
==================
* Corregir páginas 404 y 500.

2.3.0 (2015-01-27)
==================
* Posibilidad de retornar resultados al hacer click sobre fechas.

2.2.0 (2015-01-27)
==================

* Agregado el Minem a la lista de entidades estatales.
* Conteo de resultados con coma.

2.1.0 (2015-01-27)
==================

* Ahora usando `elasticseach` para indexar la base de datos.
* Es más rápido que `whoosh`.

2.0.0 (2015-01-25)
==================

* Gran reorganización de `models`.
* Manolo unificado, usando base de datos indexada via `whoosh`.

1.1.0 (2014-11-19)
==================

* Ahora con paginación de la búsqueda de resultados.

1.0.3 (2014-09-04)
==================

* Documentación.

1.0.2 (2014-09-04)
==================

* Agregando logo.

1.0.1 (2014-09-02)
==================

* Actualizando dependencia ``requests``

1.0.0 (2014-08-31)
==================

* Empaquetado como *app* para Django.
